@@ -2,17 +2,17 @@ from .or_ import or_
 
 
 def nor(a=False, b=False, c=False, d=False, e=False, f=False, g=False, h=False):
-  """Checks if all values are false. `📘`_
+  """Checks if all values are False. `📘`_
 
   - a: 1st boolean
   - b: 2nd boolean
   - ...
 
   Example:
-    >>> nor(false, false)               == true
-    >>> nor(true, false)                == false
-    >>> nor(false, false, false, false) == true
-    >>> nor(false, false, true, false)  == false
+    >>> nor(False, False)               == True
+    >>> nor(True, False)                == False
+    >>> nor(False, False, False, False) == True
+    >>> nor(False, False, True, False)  == False
 
   .. _📘:
     https://github.com/python3f/extra-boolean/wiki/nor
